@@ -5,7 +5,7 @@
  * later. See the COPYING file.
  *
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @copyright Christoph Wurst 2015, 2016
+ * @copyright Christoph Wurst 2017
  */
 
 define(function(require) {
@@ -18,6 +18,10 @@ define(function(require) {
 	 * @class Attachment
 	 */
 	var Attachment = Backbone.Model.extend({
+		defaults: {
+			isLocal: false
+		},
+
 		initialize: function() {
 			if (_.isUndefined(this.get('id'))) {
 				this.set('id', _.uniqueId());
