@@ -383,8 +383,8 @@ define(function(require) {
 				subject: message.subject,
 				body: message.body,
 				attachments: message.attachments,
-				folderId: options.repliedMessage ? options.repliedMessage.get('folderId') : undefined,
-				messageId: options.repliedMessage ? options.repliedMessage.get('messageId') : undefined,
+				folderId: options.repliedMessage ? options.repliedMessage.folder.get('id') : undefined,
+				messageId: options.repliedMessage ? options.repliedMessage.get('id') : undefined,
 				draftUID: options.draftUID,
 				aliasId: options.aliasId
 			}
