@@ -21,6 +21,8 @@ OC.L10N.register(
     "Error while creating the account: " : "Fehler beim Erstellen des Kontos:",
     "Unknown error" : "Unbekannter Fehler",
     "All inboxes" : "Alle Posteingänge",
+    "you" : "Sie",
+    "Send message to {email}" : "Nachricht an {email} senden",
     "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
     "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} konnte nicht geladen werden",
     "There was a problem loading {tag}{name}{endtag}" : "Beim Laden von {tag}{name}{endtag} ist ein Problem aufgetreten",
@@ -28,6 +30,8 @@ OC.L10N.register(
     "Unable to load the desired message" : "Gewünschte Nachricht konnte nicht geladen werden",
     "There was a problem loading the message" : "Beim Laden der Nachricht trat ein Fehler auf",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n neue Nachricht\nvon {from}","%n neue Nachrichten\nvon {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
     "Show all folders" : "Alle Ordner anzeigen",
     "Collapse folders" : "Ordner einklappen",
     "Error while deleting account." : "Fehler beim Löschen des Kontos.",
@@ -41,8 +45,6 @@ OC.L10N.register(
     "An unknown error occurred" : "Unbekannter Fehler aufgetreten",
     "Opening HTML drafts is not supported yet." : "Das Öffnen von HTML-Entwürfen wird noch nicht unterstützt.",
     "Draft saved!" : "Entwurf gespeichert!",
-    "you" : "Sie",
-    "Send message to {email}" : "Nachricht an {email} senden",
     "No writable calendars found" : "Keine beschreibbaren Kalender gefunden",
     "Error while importing the calendar event" : "Fehler beim Importieren des Kalenderereignis",
     "Error while downloading calendar event" : "Fehler beim Herunterladen des Kalenderereignis",
