@@ -30,6 +30,8 @@ OC.L10N.register(
     "Unable to load the desired message" : "Unable to load the desired message",
     "There was a problem loading the message" : "There was a problem loading the message",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
     "Show all folders" : "Show all folders",
     "Collapse folders" : "Collapse folders",
     "Error while deleting account." : "Error whilst deleting account.",
@@ -47,6 +49,7 @@ OC.L10N.register(
     "Error while importing the calendar event" : "Error whilst importing the calendar event",
     "Error while downloading calendar event" : "Error whilst downloading calendar event",
     "Error while loading messages." : "Error whilst loading messages.",
+    "Error while refreshing messages." : "Error while refreshing messages.",
     "Setting up your account" : "Setting up your account",
     "Inbox" : "Inbox",
     "Sent" : "Sent",
