@@ -21,6 +21,8 @@ OC.L10N.register(
     "Error while creating the account: " : "Fout bij het creëren van een account:",
     "Unknown error" : "Onbekende fout",
     "All inboxes" : "Alle postvakken",
+    "you" : "jou",
+    "Send message to {email}" : "Verstuur email aan {email}",
     "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} kon niet worden geladen",
     "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
@@ -28,6 +30,7 @@ OC.L10N.register(
     "Unable to load the desired message" : "Gewenste bericht kon niet worden geladen",
     "There was a problem loading the message" : "Het laden van het bericht was problematisch",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "Nextcloud Mail" : "Nextcloud E-mail",
     "Show all folders" : "Laat alle mappen zien",
     "Collapse folders" : "Mappen inklappen",
     "Error while deleting account." : "Fout bij verwijderen account.",
@@ -41,12 +44,11 @@ OC.L10N.register(
     "An unknown error occurred" : "Een onbekend probleem vond plaats",
     "Opening HTML drafts is not supported yet." : "Openen concept HTML wordt nog niet ondersteund.",
     "Draft saved!" : "Concept opgeslagen!",
-    "you" : "jou",
-    "Send message to {email}" : "Verstuur email aan {email}",
     "No writable calendars found" : "Geen beschijfbare agenda's gevonden",
     "Error while importing the calendar event" : "Fout bij importeren agenda-afspraak",
     "Error while downloading calendar event" : "Fout bij downloaden agenda-afspraak",
     "Error while loading messages." : "Fout bij laden berichten.",
+    "Error while refreshing messages." : "Foutmelding tijdens verversen van berichten.",
     "Setting up your account" : "Je account opzetten",
     "Inbox" : "Postvak in",
     "Sent" : "Verzonden",
