@@ -5,7 +5,7 @@ OC.L10N.register(
     "Error while loading the accounts." : "Błąd podczas ładowania kont.",
     "Error while loading the selected account." : "Błąd podczas ładowania zaznaczonego konta.",
     "Can not load this folder." : "Nie można załadować tego folderu.",
-    "Loading {folder}" : "Wczytuje {folder}",
+    "Loading {folder}" : "Wczytuję {folder}",
     "Searching for {query}" : "Wyszukiwanie {query}",
     "Error while deleting message." : "Błąd podczas usuwania wiadomości.",
     "Forwarded message" : "Wiadomość przekazana",
@@ -21,6 +21,8 @@ OC.L10N.register(
     "Error while creating the account: " : "Błąd podczas tworzenia konta:",
     "Unknown error" : "Nieznany błąd",
     "All inboxes" : "Wszystkie skrzynki odbiorcze",
+    "you" : "Ty",
+    "Send message to {email}" : "Wyślij wiadomość do {email}",
     "Could not load {tag}{name}{endtag}" : "Nie można załadować {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Nie możemy załadować {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Wystąpił problem podczas wczytywania {tag}{name}{endtag}",
@@ -28,6 +30,7 @@ OC.L10N.register(
     "Unable to load the desired message" : "Nie można wczytać żądaną wiadomość",
     "There was a problem loading the message" : "Wystąpił problem podczas ładowania wiadomości.",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "Nextcloud Mail" : "Poczta Nextcloud",
     "Show all folders" : "Wyświetl wszystkie foldery",
     "Collapse folders" : "Zwiń foldery",
     "Error while deleting account." : "Błąd podczas usuwania konta.",
@@ -41,12 +44,11 @@ OC.L10N.register(
     "An unknown error occurred" : "Wystąpił nieznany błąd",
     "Opening HTML drafts is not supported yet." : "Otwieranie wiadomości roboczych w HTML nie jest jeszcze wspierane.",
     "Draft saved!" : "Szkic został zapisany!",
-    "you" : "Ty",
-    "Send message to {email}" : "Wyślij wiadomość do {email}",
     "No writable calendars found" : "Nie znaleziono zapisywalnych kalendarzy.",
     "Error while importing the calendar event" : "Wystąpił błąd podczas importowania zdarzenia z kalendarza",
     "Error while downloading calendar event" : "Wystąpił błąd podczas pobierania zdarzenia z kalendarza",
     "Error while loading messages." : "Błąd podczas ładowania wiadomości.",
+    "Error while refreshing messages." : "Błąd podczas odświeżania wiadomości.",
     "Setting up your account" : "Skonfiguruj swoje konto",
     "Inbox" : "Odbiorcza",
     "Sent" : "Wysłane",
