@@ -21,6 +21,8 @@ OC.L10N.register(
     "Error while creating the account: " : "Erro ao criar a conta:",
     "Unknown error" : "Erro desconhecido",
     "All inboxes" : "Todas as caixas de entrada",
+    "you" : "você",
+    "Send message to {email}" : "Enviar mensagem para {email}",
     "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
@@ -28,6 +30,8 @@ OC.L10N.register(
     "Unable to load the desired message" : "Não foi possível carregar a mensagem desejada",
     "There was a problem loading the message" : "Ocorreu um problema ao carregar a mensagem",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
+    "Nextcloud Mail" : "Email Nextcloud",
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Esconder as pastas",
     "Error while deleting account." : "Erro ao excluir a conta.",
@@ -41,8 +45,6 @@ OC.L10N.register(
     "An unknown error occurred" : "Ocorreu um erro desconhecido",
     "Opening HTML drafts is not supported yet." : "A abertura de rascunhos do HTML ainda não é suportada.",
     "Draft saved!" : "Rascunho salvo!",
-    "you" : "você",
-    "Send message to {email}" : "Enviar mensagem para {email}",
     "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
     "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
     "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
