@@ -2,51 +2,54 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Почта",
-    "Error while loading the accounts." : "Ошибка при загрузке учётных записей",
+    "Error while loading the accounts." : "Ошибка загрузки учётных записей.",
     "Error while loading the selected account." : "Ошибка загрузки выбранного аккаунта.",
-    "Can not load this folder." : "Невозможно загрузить этот каталог.",
-    "Loading {folder}" : "Загрузка {folder}",
+    "Can not load this folder." : "Невозможно загрузить эту папку.",
+    "Loading {folder}" : "Загрузка папки «{folder}»",
     "Searching for {query}" : "Поиск {query}",
     "Error while deleting message." : "Ошибка при удалении сообщения.",
     "Forwarded message" : "Пересланное сообщение",
     "Choose a folder to store the attachment in" : "Выберите каталог для хранения вложений",
-    "Attachments saved to Files." : "Вложения сохранены в файлах",
-    "Attachment saved to Files." : "Вложение сохранено в файлах",
+    "Attachments saved to Files." : "Вложения сохранены в файлах.",
+    "Attachment saved to Files." : "Вложение сохранено в файлах.",
     "Error while saving attachments to Files." : "Ошибка сохранения вложений в файлах.",
     "Error while saving attachment to Files." : "Ошибка сохранения вложения в файлах.",
     "Message flag could not be set." : "Не удалось установить флажок сообщения.",
-    "Could not move message." : "Невозможно переместить сообщение",
+    "Could not move message." : "Невозможно переместить сообщение.",
     "Invalid account" : "Неверная учётная запись",
-    "Invalid folder" : "Неверный каталог",
-    "Error while creating the account: " : "Ошибка при создании учётной записи:",
+    "Invalid folder" : "Неверная папка",
+    "Error while creating the account: " : "Ошибка создания учётной записи:",
     "Unknown error" : "Неизвестная ошибка",
     "All inboxes" : "Все входящие",
-    "Could not load {tag}{name}{endtag}" : "Не может быть загружено {tag}{name}{endtag}",
-    "We couldn’t load {tag}{name}{endtag}" : "Мы не можем загрузить {tag}{name}{endtag}",
+    "you" : "вы",
+    "Send message to {email}" : "Отправить сообщения на {email}",
+    "Could not load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
+    "We couldn’t load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Проблема при загрузке {tag}{name}{endtag}",
     "We couldn’t load your message" : "Мы не смогли загрузить сообщение",
-    "Unable to load the desired message" : "Невозможно загрузить данное сообщение",
+    "Unable to load the desired message" : "Невозможно загрузить указанное сообщение",
     "There was a problem loading the message" : "Проблемы при загрузке сообщения",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "Show all folders" : "Показать все каталоги",
-    "Collapse folders" : "Свернуть каталоги",
-    "Error while deleting account." : "Ошибка при удалении учётной записи.",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
+    "Nextcloud Mail" : "Почта Nextcloud",
+    "Show all folders" : "Показать все папки",
+    "Collapse folders" : "Свернуть папки",
+    "Error while deleting account." : "Ошибка удаления учётной записи.",
     "Choose a file to add as attachment" : "Выбрать файл для вложения",
     "An error occurred while uploading {fname}" : "При загрузке {fname} произошла ошибка",
-    "Reply" : "Ответ",
+    "Reply" : "Ответить",
     "Send" : "Отправить",
-    "Sending …" : "Отправляется ...",
+    "Sending …" : "Отправка...",
     "Message sent!" : "Сообщение отправлено!",
     "Server error" : "Ошибка сервера",
     "An unknown error occurred" : "Произошла неизвестная ошибка",
     "Opening HTML drafts is not supported yet." : "Работа с черновиками HTML пока не поддерживается.",
     "Draft saved!" : "Черновик сохранен!",
-    "you" : "вы",
-    "Send message to {email}" : "Отправить сообщения на {email}",
     "No writable calendars found" : "Календари доступные для записи не найдены",
     "Error while importing the calendar event" : "Ошибка при импорте календарного события",
     "Error while downloading calendar event" : "Ошибка при скачивании календарного события",
     "Error while loading messages." : "Ошибка пр загрузке изображений.",
+    "Error while refreshing messages." : "Ошибка обновления списка писем.",
     "Setting up your account" : "Настраивается учётная запись",
     "Inbox" : "Входящие",
     "Sent" : "Отправленные",
@@ -57,10 +60,10 @@ OC.L10N.register(
     "All" : "Все",
     "Favorites" : "Избранное",
     "Creating account failed: " : "Ошибка создания учетной записи:",
-    "Auto detect failed. Please use manual mode." : "Не удалось определить настройки автоматически. Воспользуйтесь ручным режимом.",
+    "Auto detect failed. Please use manual mode." : "Не удалось автоматически определить настройки. Воспользуйтесь ручным режимом.",
     "Delete permanently" : "Удалить окончательно",
     "& others" : "и другие",
-    "Error loading message" : "Ошибка при загрузке сообщения",
+    "Error loading message" : "Ошибка загрузки сообщения",
     "Settings" : "Настройки",
     "Forwarding to %s" : "Пересылка на %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Нажмите здесь, если не запустилось автоматическое перенаправление в течение нескольких секунд.",
@@ -68,19 +71,19 @@ OC.L10N.register(
     "The link leads to %s" : "Эта ссылка ведёт на %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>.",
     "Continue to %s" : "Продолжать %s",
-    "Delete account" : "Удалить аккаунт",
+    "Delete account" : "Удалить учётную запись",
     "Try again" : "Попытаться снова",
-    "New message" : "Новое сообщение",
-    "Account Settings" : "Настройки аккаунта",
+    "New message" : "Создать сообщение",
+    "Account Settings" : "Настройки учётной записи",
     "Aliases" : "Псевдонимы",
     "Mail address" : "Почтовый адрес",
     "Display Name" : "Отображаемое имя",
     "Save" : "Сохранить",
-    "Keyboard shortcuts" : "Горячие клавиши",
-    "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих сочетаний клавиш.",
+    "Keyboard shortcuts" : "Комбинации клавиш",
+    "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих комбинаций клавиш.",
     "Compose new message" : "Создать новое сообщение",
-    "Newer message" : "Новейшее сообщение",
-    "Older message" : "Старейшее сообщение",
+    "Newer message" : "Самое новое сообщение",
+    "Older message" : "Самое старое сообщение",
     "Toggle star" : "Переключить отметку звёздочкой",
     "Toggle unread" : "Переключить отметку прочтения",
     "Delete" : "Удалить",
@@ -95,26 +98,26 @@ OC.L10N.register(
     "IMAP security" : "Безопасность IMAP",
     "None" : "Отсутствует",
     "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP-порт",
+    "IMAP Port" : "порт IMAP",
     "IMAP User" : "IMAP-пользователь",
-    "IMAP Password" : "IMAP-пароль",
-    "SMTP Host" : "SMTP-сервер",
-    "SMTP security" : "Безопасность SMTP",
-    "SMTP Port" : "SMTP-порт",
-    "SMTP User" : "Пользователь SMTP",
-    "SMTP Password" : "Пароль SMTP",
+    "IMAP Password" : "пароль IMAP",
+    "SMTP Host" : "сервер SMTP",
+    "SMTP security" : "безопасность SMTP",
+    "SMTP Port" : "порт SMTP",
+    "SMTP User" : "пользователь SMTP",
+    "SMTP Password" : "пароль SMTP",
     "Connect" : "Соединить",
-    "from" : "от кого",
+    "from" : "от",
     "to" : "кому",
     "cc" : "копия",
     "bcc" : "скрытая копия",
     "Subject" : "Тема",
     "Save all to Files" : "Сохранить все в файлы",
-    "Add mail account" : "Добавить почтовый аккаунт",
+    "Add mail account" : "Добавить почтовую учётную запись",
     "No search results for" : "Ничего не найдено для",
     "The images have been blocked to protect your privacy." : "Изображения были заблокированы для защиты вашей частной жизни.",
     "Show images from this sender" : "Показать изображения от этого отправителя",
-    "Forward" : "Вперед",
+    "Forward" : "Переслать",
     "Add attachment" : "Добавить вложение",
     "Add from Files" : "Добавить из файлов",
     "Import into calendar" : "Импортировать в календарь",
