@@ -21,6 +21,8 @@ OC.L10N.register(
     "Error while creating the account: " : "Fel när kontot skulle skapas:",
     "Unknown error" : "Okänt fel",
     "All inboxes" : "alla inkorgar",
+    "you" : "du",
+    "Send message to {email}" : "Skicka meddelande till {email}",
     "Could not load {tag}{name}{endtag}" : "Kunde inte ladda {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Vi kunde inte ladda {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Det blev ett problem när vi skulle ladda {tag}{name}{endtag}",
@@ -28,6 +30,8 @@ OC.L10N.register(
     "Unable to load the desired message" : "Kan ej ladda önskat meddelande",
     "There was a problem loading the message" : "Det blev ett problem när vi skulle ladda meddelandet",
     "{from}\n{subject}" : "{från}\n{ämne}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
     "Show all folders" : "Visa alla kataloger",
     "Collapse folders" : "Dölj mappar",
     "Error while deleting account." : "Fel vid radering av konto.",
@@ -41,8 +45,6 @@ OC.L10N.register(
     "An unknown error occurred" : "Ett okänt fel uppstod",
     "Opening HTML drafts is not supported yet." : "Att öppna HTML-utkast stöds inte än.",
     "Draft saved!" : "Utkast sparat!",
-    "you" : "du",
-    "Send message to {email}" : "Skicka meddelande till {email}",
     "No writable calendars found" : "Inga skrivbara kalendrar hittade",
     "Error while importing the calendar event" : "Fel vid import av kalenderhändelse",
     "Error while downloading calendar event" : "Fel vid nedladdning av kalenderhändelse",
